@@ -99,7 +99,7 @@ var _ = Describe("Generating fluentd config", func() {
 				},
 			},
 		}
-		results, err := generator.Generate(forwarder, forwarderSpec)
+		results, err := generator.Generate(forwarder, nil, forwarderSpec)
 		Expect(err).To(BeNil())
 		Expect(results).To(EqualTrimLines(`
   ## CLO GENERATED CONFIGURATION ###
@@ -362,14 +362,20 @@ var _ = Describe("Generating fluentd config", func() {
       remove_keys req,res,msg,name,level,v,pid,err
     </filter>
   
-    <filter k8s-audit.log**>
-      @type record_transformer
-      enable_ruby
-      <record>
-        k8s_audit_level ${record['level']}
-        level info
-      </record>
-    </filter>
+	<filter k8s-audit.log**>
+	  @type record_modifier
+	  <record>
+		k8s_audit_level ${record['level']}
+		level info
+	  </record>
+	</filter>
+	<filter openshift-audit.log**>
+	  @type record_modifier
+	  <record>
+		openshift_audit_level ${record['level']}
+		level info
+	  </record>
+	</filter>
   
     <filter **>
       @type viaq_data_model
@@ -627,7 +633,7 @@ var _ = Describe("Generating fluentd config", func() {
 				},
 			},
 		}
-		results, err := generator.Generate(forwarder, forwarderSpec)
+		results, err := generator.Generate(forwarder, nil, forwarderSpec)
 		Expect(err).To(BeNil())
 		Expect(results).To(EqualTrimLines(`
 			## CLO GENERATED CONFIGURATION ### 
@@ -879,13 +885,19 @@ var _ = Describe("Generating fluentd config", func() {
 				</filter>
 
 				<filter k8s-audit.log**>
-				  @type record_transformer
-				  enable_ruby
+     			  @type record_modifier
 				  <record>
 				    k8s_audit_level ${record['level']}
 				    level info
 				  </record>
 				</filter>
+				<filter openshift-audit.log**>
+				  @type record_modifier
+				  <record>
+                    openshift_audit_level ${record['level']}
+					level info
+				  </record>
+				</filter>
 
 				<filter **>
 					@type viaq_data_model
@@ -1046,7 +1058,7 @@ var _ = Describe("Generating fluentd config", func() {
 	})
 
 	It("should produce well formed fluent.conf", func() {
-		results, err := generator.Generate(forwarder, forwarderSpec)
+		results, err := generator.Generate(forwarder, nil, forwarderSpec)
 		Expect(err).To(BeNil())
 		Expect(results).To(EqualTrimLines(`
 			## CLO GENERATED CONFIGURATION ### 
@@ -1363,11 +1375,17 @@ var _ = Describe("Generating fluentd config", func() {
 				</filter>
 
 				<filter k8s-audit.log**>
-				  @type record_transformer
-				  enable_ruby
+				  @type record_modifier
 				  <record>
-				    k8s_audit_level ${record['level']}
-				    level info
+					k8s_audit_level ${record['level']}
+					level info
+				  </record>
+				</filter>				  
+				<filter openshift-audit.log**>
+				  @type record_modifier
+				  <record>
+					openshift_audit_level ${record['level']}
+					level info
 				  </record>
 				</filter>
 
@@ -1935,7 +1953,7 @@ var _ = Describe("Generating fluentd config", func() {
 		func(yamlSpec, wantFluentdConf string) {
 			var spec logging.ClusterLogForwarderSpec
 			Expect(yaml.Unmarshal([]byte(yamlSpec), &spec)).To(Succeed())
-			gotFluentdConf, err := generator.Generate(&spec, nil)
+			gotFluentdConf, err := generator.Generate(&spec, nil, nil)
 			Expect(err).To(Succeed())
 			Expect(wantFluentdConf).To(EqualTrimLines(gotFluentdConf))
 		},
@@ -2213,14 +2231,20 @@ var _ = Describe("Generating fluentd config", func() {
         remove_keys req,res,msg,name,level,v,pid,err
       </filter>
     
-      <filter k8s-audit.log**>
-        @type record_transformer
-	enable_ruby
-        <record>
-          k8s_audit_level ${record['level']}
-          level info
-        </record>
-      </filter>
+	  <filter k8s-audit.log**>
+		@type record_modifier
+		<record>
+		  k8s_audit_level ${record['level']}
+		  level info
+		</record>
+	  </filter>
+	  <filter openshift-audit.log**>
+		@type record_modifier
+		<record>
+		  openshift_audit_level ${record['level']}
+		  level info
+		</record>
+	  </filter>
 
       <filter **>
         @type viaq_data_model
