@@ -348,14 +348,20 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
             remove_keys req,res,msg,name,level,v,pid,err
           </filter>
 
-          <filter k8s-audit.log**>
-            @type record_transformer
-            enable_ruby
-            <record>
-              k8s_audit_level ${record['level']}
-              level info
-            </record>
-          </filter>
+		  <filter k8s-audit.log**>
+			@type record_modifier
+			<record>
+			  k8s_audit_level ${record['level']}
+			  level info
+			</record>
+		  </filter>
+		  <filter openshift-audit.log**>
+			@type record_modifier
+			<record>
+			  openshift_audit_level ${record['level']}
+			  level info
+			</record>
+		  </filter>
 
           <filter **>
             @type viaq_data_model
@@ -510,7 +516,7 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
         </label>
       `
 
-			results, err := generator.Generate(clfSpec, fwSpec)
+			results, err := generator.Generate(clfSpec, nil, fwSpec)
 			Expect(err).Should(Succeed())
 			Expect(results).To(EqualTrimLines(legacyConf))
 		})
@@ -847,14 +853,20 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
             remove_keys req,res,msg,name,level,v,pid,err
           </filter>
 
-          <filter k8s-audit.log**>
-            @type record_transformer
-            enable_ruby
-            <record>
-              k8s_audit_level ${record['level']}
-              level info
-            </record>
-          </filter>
+		  <filter k8s-audit.log**>
+			@type record_modifier
+			<record>
+			  k8s_audit_level ${record['level']}
+			  level info
+			</record>
+		  </filter>
+		  <filter openshift-audit.log**>
+			@type record_modifier
+			<record>
+			  openshift_audit_level ${record['level']}
+			  level info
+			</record>
+		  </filter>
 
           <filter **>
             @type viaq_data_model
@@ -1011,7 +1023,7 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
         </label>
       `
 
-			results, err := generator.Generate(clfSpec, fwSpec)
+			results, err := generator.Generate(clfSpec, nil, fwSpec)
 			Expect(err).Should(Succeed())
 			Expect(results).To(EqualTrimLines(legacyConf))
 		})
@@ -1348,14 +1360,20 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
             remove_keys req,res,msg,name,level,v,pid,err
           </filter>
 
-          <filter k8s-audit.log**>
-            @type record_transformer
-            enable_ruby
-            <record>
-              k8s_audit_level ${record['level']}
-              level info
-            </record>
-          </filter>
+		  <filter k8s-audit.log**>
+			@type record_modifier
+			<record>
+			  k8s_audit_level ${record['level']}
+			  level info
+			</record>
+		  </filter>
+		  <filter openshift-audit.log**>
+			@type record_modifier
+			<record>
+			  openshift_audit_level ${record['level']}
+			  level info
+			</record>
+		  </filter>
 
           <filter **>
             @type viaq_data_model
@@ -1530,7 +1548,7 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
         </label>
       `
 
-			results, err := generator.Generate(clfSpec, fwSpec)
+			results, err := generator.Generate(clfSpec, nil, fwSpec)
 			Expect(err).Should(Succeed())
 			Expect(results).To(EqualTrimLines(legacyConf))
 		})
