@@ -262,13 +262,19 @@ const fluentConfTemplate = `{{- define "fluentConf" -}}
   </filter>
 
   <filter k8s-audit.log**>
-    @type record_transformer
-    enable_ruby
+    @type record_modifier
     <record>
       k8s_audit_level ${record['level']}
       level info
     </record>
   </filter>
+  <filter openshift-audit.log**>
+    @type record_modifier
+    <record>
+      openshift_audit_level ${record['level']}
+      level info
+    </record>
+  </filter>
 
   <filter **>
     @type viaq_data_model
@@ -621,20 +627,31 @@ const forwardTemplate = `{{- define "forward" -}}
 # https://docs.fluentd.org/v1.0/articles/in_forward
 @type forward
 heartbeat_type none
-{{ if .Target.Secret }}
+{{- with $sharedKey := .GetSecret "shared_key" }}
 <security>
   self_hostname "#{ENV['NODE_NAME']}"
-  shared_key "#{File.open('{{ .SecretPath "shared_key" }}') do |f| f.readline end.rstrip}"
+  shared_key "{{$sharedKey}}"
 </security>
+{{- end}}
+{{- if .IsTLS }}
 
 transport tls
 tls_verify_hostname false
 tls_version 'TLSv1_2'
 
-#tls_client_private_key_path {{ .SecretPath "tls.key"}}
-tls_client_cert_path {{ .SecretPath "tls.crt"}}
-tls_cert_path {{ .SecretPath "ca-bundle.crt"}}
-{{ end -}}
+{{- if not .Secret}}
+tls_insecure_mode true
+{{- end}}
+{{- with $path := .SecretPathIfFound "tls.key"}}
+tls_client_private_key_path "{{$path}}"
+{{- end}}
+{{- with $path := .SecretPathIfFound "tls.crt"}}
+tls_client_cert_path "{{$path}}"
+{{- end}}
+{{- with $path := .SecretPathIfFound "ca-bundle.crt"}}
+tls_cert_path "{{$path}}"
+{{- end}}
+{{- end}}
 
 <buffer>
   @type file
