@@ -6,13 +6,13 @@ import (
 
 	. "github.com/onsi/ginkgo"
 
-	"github.com/openshift/cluster-logging-operator/pkg/logger"
+	"github.com/ViaQ/logerr/log"
 	"github.com/openshift/cluster-logging-operator/test/helpers"
 )
 
 var _ = Describe("[Collection] Provides only a fluentd daemonset", func() {
 	_, filename, _, _ := runtime.Caller(0)
-	logger.Infof("Running %s", filename)
+	log.Info("Running ", "filename", filename)
 	var (
 		e2e        = helpers.NewE2ETestFramework()
 		components []helpers.LogComponentType
